/*____________________________________________________________________________*\
 *

 Copyright (c) 1997 John Roy. All rights reserved.

 These sources, libraries and applications are
 FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
 as long as the following conditions are adhered to.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer. 

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.

 3. Redistributions of any form whatsoever and all advertising materials 
    mentioning features must contain the following
    acknowledgment:
    "This product includes software developed by John Roy
    (http://www.johnroy.com/pi3/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE AUTHORS OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 OF THE POSSIBILITY OF SUCH DAMAGE.

 *____________________________________________________________________________*|
 *
 * $Source: PILib.h$
 * $Date: Sun Aug 10 06:42:18 1997$
 *
 Description:
\*____________________________________________________________________________*/
/* $HeaderTop:$ */

#ifndef PILIB_H_
#define PILIB_H_

#include "Pi2API.h"

/*____________________________________________________________________________*\
 *
Definitions
\*____________________________________________________________________________*/
typedef struct DLL PILibrary;

/*____________________________________________________________________________*\
 *
 Name:
	PILibrary_load

 Synopsis:
	const PILibrary *PILibrary_load( PIDB *pDB, PIConfig *pConfig,
		const char *pLibraryName )
	
 Description:
	Attempts to load the library with name pLibraryName from the 
	parsed configuration file pConfigDB.

	If pConfigDB is NULL then PIConfig_findConfiguration() is used to
	find the configuration DB from pDB.

 Notes:
 Return Values:
	On success PILibrary_load() returns a const pointer to the a new PILibrary
	object.

 Errors:
	PIAPI_EINVAL	if pDB or pLibraryName is NULL.
	PIAPI_ERROR		if another error occurred.

 See Also:
\*____________________________________________________________________________*/
PUBLIC_PIAPI const PILibrary *PILibrary_load( PIDB *pDB, PIConfig *pConfig,
	const char *pLibraryName );

/*____________________________________________________________________________*\
 *
 Name:
	PILibrary_lookup

 Synopsis:
	const PILibrary *PILibrary_lookup( PIDB *pDB, const char *pLibraryName );
	
 Description:
	Looks under the root node of pDB for a PIDB tree with a key of
	PIDBKEY_LIBRARIES, then searches within this tree for an element
	with key pLibraryName. If found this element is returned.

 Notes:
 Return Values:
	On success PILibrary_lookup() returns a const pointer to a new
	PILibrary object.

 Errors:
	PIAPI_EINVAL	if pDB or pLibraryName is NULL.
	PIAPI_ERROR		if another error occurred.

 See Also:
\*____________________________________________________________________________*/
PUBLIC_PIAPI const PILibrary *PILibrary_lookup( PIDB *pDB,
	const char *pLibrary );

/*____________________________________________________________________________*\
 *
 Name:
	PILibrary_lookupOrLoad

 Synopsis:
	const PILibrary *PILibrary_lookupOrLoad( PIDB *pDB, PIConfig *pConfig,
		const char *pLibraryName )
	
 Description:
	This function first attempts to find an existing library using
	PILibrary_lookup(). If that fails it attempts to load the library
	from the parsed configuration DB pConfigDB using PILibrary_load().

 Notes:
	See PILibrary_lookup() and PILibrary_load() for more details.

 Return Values:
	On success PILibrary_lookup() returns a const pointer to the 
	specificed PILibrary object.

 Errors:
	PIAPI_EINVAL	if pDB or pLibraryName is NULL.
	PIAPI_ERROR		if another error occurred.

 See Also:
\*____________________________________________________________________________*/
PUBLIC_PIAPI const PILibrary *PILibrary_lookupOrLoad( PIDB *pDB, 
	PIConfig *pConfig, const char *pLibraryName );

#endif	/* PILIB_H_ */

